#
# spec file for package libxtrx
#
# Copyright (c) 2020-2021 SUSE LLC
# Copyright (c) 2017-2020, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   0
%define libname libxtrx%{sover}
%define soapy_modver 0.8
%define soapy_modname soapysdr%{soapy_modver}-module-xtrx

Name:           libxtrx
Version:        0.0.0+git.20201202
Release:        4.1
Summary:        High level XTRX API
License:        LGPL-2.1-only
Group:          Development/Libraries/C and C++
URL:            http://xtrx.io
#Git-Clone:     https://github.com/xtrx-sdr/libxtrx.git
Source:         %{name}-%{version}.tar.xz
Patch1:         0001-Fix-CMake-FindQCustomPlot.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  git-core
BuildRequires:  liblms7002m-devel
BuildRequires:  pkgconfig
BuildRequires:  qcustomplot-devel
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(SoapySDR) >= 0.5.2
BuildRequires:  pkgconfig(libxtrxdsp)
BuildRequires:  pkgconfig(libxtrxll)
ExclusiveArch:  %{ix86} x86_64 aarch64 armv7hl

%description
High level API for XTRX software defined radio frontends.

%package -n %{libname}
Summary:        High level XTRX API
Group:          System/Libraries

%description -n %{libname}
High level API for XTRX software defined radio frontends.

%package devel
Summary:        Development files for libxtrx
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description devel
High level XTRX API.

This subpackage contains libraries and header files for developing
applications that want to make use of libxtrx.

%package -n xtrx-tools
Summary:        Tools for XTRX
Group:          Productivity/Hamradio/Other
Requires:       %{soapy_modname}

%description -n xtrx-tools
Tools for XTRX SDR devices.

%package -n %{soapy_modname}
Summary:        SoapySDR XTRX module
Group:          System/Libraries

%description -n %{soapy_modname}
Soapy XTRX - XTRX device support for Soapy SDR.
A Soapy module that supports XTRX devices within the Soapy API.

%prep
%autosetup -p1

%build
# FIXME: Architecture detection in the used CMake is br0ken, use FORCE_ARCH for now
%cmake \
    -DCMAKE_SHARED_LINKER_FLAGS="" \
%ifarch %{ix86} x86_64
    -DFORCE_ARCH=x86_64 \
%endif
%ifarch %{arm} aarch64
    -DFORCE_ARCH=arm \
%endif
    -DENABLE_SOAPY=ON
%make_jobs

%install
%cmake_install
install -d %{buildroot}/%{_bindir}
#install -m 0755 build/examples/xtrx_fft/mainwindow %%{buildroot}/%%{_bindir}/xtrx_fft
mv %{buildroot}/%{_libdir}/xtrx/xtrx_fft %{buildroot}/%{_bindir}/xtrx_fft
mv %{buildroot}/%{_libdir}/xtrx/test_xtrx %{buildroot}/%{_bindir}/test_xtrx
mv build/soapy/test_xtrx_soapy %{buildroot}/%{_bindir}/test_xtrx_soapy

%post   -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%license LICENSE
%doc README.md
%{_libdir}/libxtrx.so.%{sover}*

%files devel
%{_includedir}/xtrx_api.h
%{_libdir}/libxtrx.so
%{_libdir}/pkgconfig/libxtrx.pc

%files -n %{soapy_modname}
%dir %{_libdir}/SoapySDR
%dir %{_libdir}/SoapySDR/modules%{soapy_modver}
%{_libdir}/SoapySDR/modules%{soapy_modver}/libXTRXSupport.so

%files -n xtrx-tools
%{_bindir}/test_xtrx
%{_bindir}/test_xtrx_soapy
%{_bindir}/xtrx_fft

%changelog
* Fri Mar  1 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Sun Feb 13 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Build only for supported architectures
* Thu Jul 15 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Builds with SoapySDR 0.8
- Patch 0001-Fix-test_xtrx_soapy-build-issue.patch removed (not
  needed for build now)
* Thu Dec 10 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.0.0+git.20201202:
  * xtrx_open_string: properly terminate 4096-byte paramstrings
  * soapy: Fix RX stream activation by avoiding unintended
    runtime error.
  * Fix test_xtrx_soapy build issue
  * soapy: Fix the timestamp calculation of the first sample in
    the burst
  * soapy: Implement support of special mode for simultaneous Rx
    and Tx streams activation
  * soapy: add the option for setting antenna in auto mode using
    the function setAntenna()
  * soapy: set antenna in auto mode during setup stream procedure
  * soapy: Explain an internal variable purpose.
  * Fix typos in the log output.
  * add RCVEX_REPORT_GTIME to report global time on recv()
  * Set reference clock at all levels when needed.
  * Set _actual_masterclock in the SoapySDR module.
  * Remove xtrx_fe_lms7.c - we no longer support libLMS7002M.
  * Add API flags to work with time sync without seconds recovery
  * Fix compilation due to xtrx_api.h not being found
  * octoCAL: add ability to switch A/B channels in GUI
  * add new octo version
  * fix GPIO xonfiguration
  * xtrx_fe_octorx0.c: don't use absolute include paths for
    external libraries
  * build and install example
  * fix include for proper build
  * add octoRFX6 support
  * fix uninitialized variables
- Drop not longer needed patch
  * libxtrx-fix-include.patch
- Rebase and rename patch
  * libxtrx-fix-xtrx_fft.patch -> 0001-Fix-CMake-FindQCustomPlot.patch
- Add patch:
  * 0001-Fix-test_xtrx_soapy-build-issue.patch
* Thu Dec 27 2018 mardnh@gmx.de
- Update to version 0.0.0+git.20181227:
  * gpio & sync API
  * lms7_fe: fix initialization of LMS7
  * test_xtrx: fix samplerate output
  * refactor test_xtrx
  * more refactor of test_xtrx utility; fix previous compilation problem
  * add '-o' option to write data to file
  * fix logging for multidev mode
  * fix include directory for xtrx_fft
  * rework logging system
  * soapy: setMasterClockRate isn't for refclk
  * check refclk if it was set manually
  * fix test_xtrx utility to report the correct samplerate
  * fix minor problems in test_xtrx
  * fix test utility for PCIe
  * initial multidev support
  * use new LMS7 frontend by default
  * use old FE just for now
  * update for rev4
  * fix incorrect interpolation settings
  * add ability to set NCO independently
  * fix div by 0
  * add clock selection API
  * soapy: use getSampleRateRange instead of old function
  * soapy: setupStream options
  * soapy: hide warnings
  * soapy: setSampleRate in case it was never called befor running the
    RX stream (fixes some program).
  * adopt for new ll-library
  * new lml phy code adoptiion
  * Fix failed VCO tuning on fast PCs.
  * fix crashing when stream wasn'r initialized
  * more transcoding 8 to 16 bits
  * better description in CGEN selection
  * add AUTO lna selection based on LO
  * Fix RefClk selection on machines with imprecise PCIe clock.
  * xtrx_tune: fix crashing when actualfreq wasn't provided
- Remove patch:
  * libxtrx-cmake-disable-test.patch
- Add patches:
  * libxtrx-fix-include.patch
  * libxtrx-fix-xtrx_fft.patch
* Thu Apr 26 2018 mardnh@gmx.de
- Fix soapysdr subpackage name (This is xtrx and not bladeRF)
* Sun Dec 31 2017 jengelh@inai.de
- Fix RPM groups.
* Wed Dec 13 2017 mardnh@gmx.de
- Initial package, version 0.0.0+git.20171213
